Developers

Referência de API para desenvolvedores

Uma chave de API é necessária para que as solicitações sejam processadas pelo sistema. Depois que um usuário se registra, uma chave de API é gerada automaticamente para esse usuário.

Começando

Uma chave de API é necessária para que as solicitações sejam processadas pelo sistema. Depois que um usuário se registra, uma chave de API é gerada automaticamente para esse usuário. A chave de API deve ser enviada com cada solicitação (veja o exemplo completo abaixo). Se a chave de API não for enviada ou tiver expirado, ocorrerá um erro. Certifique-se de manter sua chave de API em segredo para evitar abusos.

Autenticação

Para autenticar com o sistema de API, você precisa enviar sua chave de API como um token de autorização com cada solicitação. Você pode ver o código de exemplo abaixo.

curl --location --request POST 'https://xcurt.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \ 

Taxa limite

Nossa API tem um limitador de taxa para proteger contra picos de solicitações para maximizar sua estabilidade. Nosso limitador de taxa está limitado a 30 solicitações por 1 minuto. Observe que a tarifa pode mudar de acordo com o plano contratado.

Vários cabeçalhos serão enviados juntamente com a resposta e estes podem ser examinados para determinar várias informações sobre a solicitação.

X-RateLimit-Limit: 30X-RateLimit-Remaining: 29X-RateLimit-Reset: TIMESTAMP

Tratamento de respostas

Todas as respostas da API são retornadas no formato JSON por padrão. Para converter isso em dados utilizáveis, a função apropriada precisará ser usada de acordo com o idioma. Em PHP, a função json_decode() pode ser usada para converter os dados em um objeto (padrão) ou um array (defina o segundo parâmetro como true). É muito importante verificar a chave de erro, pois ela fornece informações sobre se houve ou não um erro. Você também pode verificar o código do cabeçalho.

{
    "error": 1,
    "message": "An error occurred"
}

Campanhas

Campanhas de lista

GET https://xcurt.com/api/campaigns?limit=2&page=1

Para obter suas campanhas através da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/campaigns?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "campaigns": [
            {
                "id": 1,
                "name": "Sample Campaign",
                "public": false,
                "rotator": false,
                "list": "https:\/\/domain.com\/u\/admin\/list-1"
            },
            {
                "id": 2,
                "domain": "Facebook Campaign",
                "public": true,
                "rotator": "https:\/\/domain.com\/r\/test",
                "list": "https:\/\/domain.com\/u\/admin\/test-2"
            }
        ]
    }
}

Crie uma campanha

POST https://xcurt.com/api/campaign/add

Uma campanha pode ser adicionada usando este terminal.

Parâmetro UTM Descrição
name (Opcional) Nome da campanha
slug (opcional) Slug Rotador
public (opcional) Acesso
curl --location --request POST 'https://xcurt.com/api/campaign/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Campaign",
    "slug": "new-campaign",
    "public": true
}'

Resposta do servidor

{
    "error": 0,
    "id": 3,
    "domain": "New Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/new-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/new-campaign-3"
}
POST https://xcurt.com/api/campaign/:campaignid/assign/:linkid

Um link curto pode ser atribuído a uma campanha usando esse terminal. O terminal requer o ID da campanha e o ID do link curto.

curl --location --request POST 'https://xcurt.com/api/campaign/:campaignid/assign/:linkid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "Link successfully added to the campaign."
}

Atualizar campanha

PUT https://xcurt.com/api/campaign/:id/update

Para atualizar uma campanha, você precisa enviar dados válidos no JSON por meio de uma solicitação de put. Os dados devem ser enviados como o corpo bruto da sua solicitação, conforme mostrado abaixo. O exemplo abaixo mostra todos os parâmetros que você pode enviar, mas você não precisa enviar tudo (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
name (Necessário) Nome da campanha
slug (opcional) Slug Rotador
public (opcional) Acesso
curl --location --request PUT 'https://xcurt.com/api/campaign/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Twitter Campaign",
    "slug": "twitter-campaign",
    "public": true
}'

Resposta do servidor

{
    "error": 0,
    "id": 3,
    "domain": "Twitter Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/twitter-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/twitter-campaign-3"
}

Excluir campanha

DELETE https://xcurt.com/api/campaign/:id/delete

Para excluir uma campanha, você precisa enviar uma solicitação de exclusão.

curl --location --request DELETE 'https://xcurt.com/api/campaign/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "Campaign has been deleted successfully."
}

Canais de lista

GET https://xcurt.com/api/channels?limit=2&page=1

Para obter seus canais através da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/channels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "channels": [
            {
                "id": 1,
                "name": "Channel 1",
                "description": "Description of channel 1",
                "color": "#000000",
                "starred": true
            },
            {
                "id": 2,
                "name": "Channel 2",
                "description": "Description of channel 2",
                "color": "#FF0000",
                "starred": false
            }
        ]
    }
}

Listar itens de canal

GET https://xcurt.com/api/channel/:id?limit=1&page=1

Para obter itens em um canal selecionado por meio da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/channel/:id?limit=1&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "items": [
            {
                "type": "links",
                "id": 1,
                "title": "My Sample Link",
                "preview": "https:\/\/google.com",
                "link": "https:\/\/xcurt.com\/google",
                "date": "2022-05-12"
            },
            {
                "type": "bio",
                "id": 1,
                "title": "My Sample Bio",
                "preview": "https:\/\/xcurt.com\/mybio",
                "link": "https:\/\/xcurt.com\/mybio",
                "date": "2022-06-01"
            }
        ]
    }
}

Criar um canal

POST https://xcurt.com/api/channel/add

Um canal pode ser adicionado usando este terminal.

Parâmetro UTM Descrição
name (requerido) Nome do canal
description (opcional) Descrição do canal
color (opcional) Cor de crachá do canal (hexadecimal)
starred (opcional) estrela o canal ou não (verdadeiro ou falso)
curl --location --request POST 'https://xcurt.com/api/channel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}'

Resposta do servidor

{
    "error": 0,
    "id": 3,
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}

Atribuir um item a um canal

POST https://xcurt.com/api/channel/:channelid/assign/:type/:itemid

Um item pode ser atribuído a qualquer canal enviando uma solicitação com o ID do canal, tipo de item (links, bio ou QR) e ID do item.

Parâmetro UTM Descrição
:channelid (NECESSÁRIO) ID do canal
:type (requerido) links ou bio ou qr
:itemid (requerido) ID do item
curl --location --request POST 'https://xcurt.com/api/channel/:channelid/assign/:type/:itemid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "Item successfully added to the channel."
}

Atualizar canal

PUT https://xcurt.com/api/channel/:id/update

Para atualizar um canal, você precisa enviar dados válidos no JSON por meio de uma solicitação de put. Os dados devem ser enviados como o corpo bruto da sua solicitação, conforme mostrado abaixo. O exemplo abaixo mostra todos os parâmetros que você pode enviar, mas você não precisa enviar tudo (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
name (opcional) Nome do canal
description (opcional) Descrição do canal
color (opcional) Cor de crachá do canal (hexadecimal)
starred (opcional) estrela o canal ou não (verdadeiro ou falso)
curl --location --request PUT 'https://xcurt.com/api/channel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Acme Corp",
    "description": "channel for items for Acme Corp",
    "color": "#FFFFFF",
    "starred": false
}'

Resposta do servidor

{
    "error": 0,
    "message": "Channel has been updated successfully."
}

Excluir canal

DELETE https://xcurt.com/api/channel/:id/delete

Para excluir um canal, você precisa enviar uma solicitação de exclusão. Todos os itens também não serão atribuídos.

curl --location --request DELETE 'https://xcurt.com/api/channel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "Channel has been deleted successfully."
}

Obtenha conta

GET https://xcurt.com/api/account

Para obter informações sobre a conta, você pode enviar uma solicitação para este terminal e ele retornará dados na conta.

curl --location --request GET 'https://xcurt.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "data": {
        "id": 1,
        "email": "sample@domain.com",
        "username": "sampleuser",
        "avatar": "https:\/\/domain.com\/content\/avatar.png",
        "status": "pro",
        "expires": "2022-11-15 15:00:00",
        "registered": "2020-11-10 18:01:43"
    }
}

Conta de atualização

PUT https://xcurt.com/api/account/update

Para atualizar as informações da conta, você pode enviar uma solicitação a este endpoint e ele atualizará os dados da conta.

curl --location --request PUT 'https://xcurt.com/api/account/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "email": "newemail@google.com",
    "password": "NewPassword1"
}'

Resposta do servidor

{
    "error": 0,
    "message": "Account has been successfully updated."
}

Domínios de marca

Listar domínios da marca

GET https://xcurt.com/api/domains?limit=2&page=1

Para obter seus domínios de marca através da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/domains?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "domains": [
            {
                "id": 1,
                "domain": "https:\/\/domain1.com",
                "redirectroot": "https:\/\/rootdomain.com",
                "redirect404": "https:\/\/rootdomain.com\/404"
            },
            {
                "id": 2,
                "domain": "https:\/\/domain2.com",
                "redirectroot": "https:\/\/rootdomain2.com",
                "redirect404": "https:\/\/rootdomain2.com\/404"
            }
        ]
    }
}

Crie um domínio de marca

POST https://xcurt.com/api/domain/add

Um domínio pode ser adicionado usando este terminal. Verifique se o domínio está apontado corretamente para o nosso servidor.

Parâmetro UTM Descrição
domain (necessário) domínio de marca, incluindo HTTP ou HTTPS
redirectroot (opcional) Raiz redireciona quando alguém visita seu domínio
redirect404 (Opcional) Redirecionar 404 personalizado
curl --location --request POST 'https://xcurt.com/api/domain/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "domain": "https:\/\/domain1.com",
    "redirectroot": "https:\/\/rootdomain.com",
    "redirect404": "https:\/\/rootdomain.com\/404"
}'

Resposta do servidor

{
    "error": 0,
    "id": 1
}

Atualizar domínio

PUT https://xcurt.com/api/domain/:id/update

Para atualizar um domínio de marca, você precisa enviar dados válidos no JSON por meio de uma solicitação de put. Os dados devem ser enviados como o corpo bruto da sua solicitação, conforme mostrado abaixo. O exemplo abaixo mostra todos os parâmetros que você pode enviar, mas você não precisa enviar tudo (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
redirectroot (opcional) Raiz redireciona quando alguém visita seu domínio
redirect404 (Opcional) Redirecionar 404 personalizado
curl --location --request PUT 'https://xcurt.com/api/domain/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "redirectroot": "https:\/\/rootdomain-new.com",
    "redirect404": "https:\/\/rootdomain-new.com\/404"
}'

Resposta do servidor

{
    "error": 0,
    "message": "Domain has been updated successfully."
}

Excluir domínio

DELETE https://xcurt.com/api/domain/:id/delete

Para excluir um domínio, você precisa enviar uma solicitação de exclusão.

curl --location --request DELETE 'https://xcurt.com/api/domain/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "Domain has been deleted successfully."
}

List Files

GET https://xcurt.com/api/files?limit=2&page=1

Get all of your files. You can also search by name.

Parâmetro UTM Descrição
name (optional) Search for a file by name
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/files?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "result": 3,
    "perpage": 15,
    "currentpage": 1,
    "nextpage": null,
    "maxpage": 1,
    "list": [
        {
            "id": 1,
            "name": "My Photo",
            "downloads": 10,
            "shorturl": "https:\/\/xcurt.com\/DRqQM",
            "date": "2022-08-09 17:00:00"
        },
        {
            "id": 2,
            "name": "My Documents",
            "downloads": 15,
            "shorturl": "https:\/\/xcurt.com\/oWJQG",
            "date": "2022-08-10 17:01:00"
        },
        {
            "id": 3,
            "name": "My Files",
            "downloads": 5,
            "shorturl": "https:\/\/xcurt.com\/IjDfT",
            "date": "2022-08-11 19:01:00"
        }
    ]
}

Upload a file

POST https://xcurt.com/api/files/upload/:filename?name=My+File

Upload a file by sending the binary data as the post body. You need to send the file name including the extension instead of :filename in the url (e.g. brandkit.zip). You can set options by sending the following parameters.

Parâmetro UTM Descrição
name (optional) File name
custom (opcional) Alias ​​personalizadas em vez de alias aleatórias.
domain (opcional) domínio personalizado
password (opcional) Proteção de senha
expiry (optional) Expiration for the download example 2021-09-28
maxdownloads (optional) Maximum number of downloads
curl --location --request POST 'https://xcurt.com/api/files/upload/:filename?name=My+File' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '"BINARY DATA"'

Resposta do servidor

{
    "error": 0,
    "id": 1,
    "shorturl": "https:\/\/xcurt.com\/wGXOc"
}

Liste pixels

GET https://xcurt.com/api/pixels?limit=2&page=1

Para obter seus códigos de pixels através da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/pixels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "pixels": [
            {
                "id": 1,
                "type": "gtmpixel",
                "name": "GTM Pixel",
                "tag": "GA-123456789",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "twitterpixel",
                "name": "Twitter Pixel",
                "tag": "1234567",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Crie um pixel

POST https://xcurt.com/api/pixel/add

Um pixel pode ser criado usando este terminal. Você precisa enviar o tipo de pixel e a tag.

Parâmetro UTM Descrição
type (required) gtmpixel | gapixel | fbpixel | adwordspixel | linkedinpixel | twitterpixel | adrollpixel | quorapixel | pinterest | bing | snapchat | reddit | tiktok
name (requerido) Nome personalizado para o seu pixel
tag (exigido) A tag para o pixel
curl --location --request POST 'https://xcurt.com/api/pixel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "gtmpixel",
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Resposta do servidor

{
    "error": 0,
    "id": 1
}

Atualizar pixel

PUT https://xcurt.com/api/pixel/:id/update

Para atualizar um pixel, você precisa enviar dados válidos no JSON por meio de uma solicitação de put. Os dados devem ser enviados como o corpo bruto da sua solicitação, conforme mostrado abaixo. O exemplo abaixo mostra todos os parâmetros que você pode enviar, mas você não precisa enviar tudo (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
name (Opcional) Nome personalizado para o seu pixel
tag (exigido) A tag para o pixel
curl --location --request PUT 'https://xcurt.com/api/pixel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Resposta do servidor

{
    "error": 0,
    "message": "Pixel has been updated successfully."
}

Exclua pixel

DELETE https://xcurt.com/api/pixel/:id/delete

Para excluir um pixel, você precisa enviar uma solicitação de exclusão.

curl --location --request DELETE 'https://xcurt.com/api/pixel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "Pixel has been deleted successfully."
}

QR Codes Personalizados

Liste os códigos QR

GET https://xcurt.com/api/qr?limit=2&page=1

Para obter seus códigos QR através da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/qr?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "qrs": [
            {
                "id": 2,
                "link": "https:\/\/xcurt.com\/qr\/a2d5e",
                "scans": 0,
                "name": "Google",
                "date": "2020-11-10 18:01:43"
            },
            {
                "id": 1,
                "link": "https:\/\/xcurt.com\/qr\/b9edfe",
                "scans": 5,
                "name": "Google Canada",
                "date": "2020-11-10 18:00:25"
            }
        ]
    }
}

Obtenha um único código QR

GET https://xcurt.com/api/qr/:id

Para obter detalhes para um único código QR através da API, você pode usar esse terminal.

curl --location --request GET 'https://xcurt.com/api/qr/:id' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "details": {
        "id": 1,
        "link": "https:\/\/xcurt.com\/qr\/b9edfe",
        "scans": 5,
        "name": "Google Canada",
        "date": "2020-11-10 18:00:25"
    },
    "data": {
        "clicks": 1,
        "uniqueClicks": 1,
        "topCountries": {
            "Unknown": "1"
        },
        "topReferrers": {
            "Direct, email and other": "1"
        },
        "topBrowsers": {
            "Chrome": "1"
        },
        "topOs": {
            "Windows 10": "1"
        },
        "socialCount": {
            "facebook": 0,
            "twitter": 0,
            "instagram": 0
        }
    }
}

Crie um código QR

POST https://xcurt.com/api/qr/add

Para criar um código QR, você precisa enviar dados válidos no JSON por meio de uma solicitação de postagem. Os dados devem ser enviados como o corpo bruto da sua solicitação, conforme mostrado abaixo. O exemplo abaixo mostra todos os parâmetros que você pode enviar, mas você não precisa enviar tudo (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
type (necessário) texto | vcard | link | Email | Telefone | sms | Wi-fi
data (exigido) Os dados a serem incorporados dentro do código QR. Os dados podem ser string ou matriz, dependendo do tipo
background (opcional) RGB Cor, por exemplo RGB (255.255.255)
foreground (opcional) RGB Cor, por exemplo RGB (0,0,0)
logo (opcional) caminho para o logotipo png ou jpg
name (Opcional) Nome do Código QR
curl --location --request POST 'https://xcurt.com/api/qr/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png",
    "name": "QR Code API"
}'

Resposta do servidor

{
    "error": 0,
    "id": 3,
    "link": "https:\/\/xcurt.com\/qr\/a58f79"
}

Atualize o código QR

PUT https://xcurt.com/api/qr/:id/update

Para atualizar um código QR, você precisa enviar dados válidos no JSON por meio de uma solicitação de put. Os dados devem ser enviados como o corpo bruto da sua solicitação, conforme mostrado abaixo. O exemplo abaixo mostra todos os parâmetros que você pode enviar, mas você não precisa enviar tudo (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
data (exigido) Os dados a serem incorporados dentro do código QR. Os dados podem ser string ou matriz, dependendo do tipo
background (opcional) RGB Cor, por exemplo RGB (255.255.255)
foreground (opcional) RGB Cor, por exemplo RGB (0,0,0)
logo (opcional) caminho para o logotipo png ou jpg
curl --location --request PUT 'https://xcurt.com/api/qr/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png"
}'

Resposta do servidor

{
    "error": 0,
    "message": "QR has been updated successfully."
}

Exclua um código QR

DELETE https://xcurt.com/api/qr/:id/delete

Para excluir um código QR, você precisa enviar uma solicitação de exclusão.

curl --location --request DELETE 'https://xcurt.com/api/qr/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": 0,
    "message": "QR Code has been deleted successfully."
}

Sobreposições de CTA

Liste sobreposições de CTA

GET https://xcurt.com/api/overlay?limit=2&page=1

Para obter sobreposições de CTA através da API, você pode usar esse terminal. Você também pode filtrar dados (consulte a tabela para obter mais informações).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/overlay?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "cta": [
            {
                "id": 1,
                "type": "message",
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "contact",
                "name": "Contact Page",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Splash personalizado

Liste um respingo personalizado

GET https://xcurt.com/api/splash?limit=2&page=1

To get Splash Pages via the API, you can use this endpoint. You can also filter data (See table for more info).

Parâmetro UTM Descrição
limit (opcional) por resultado dos dados da página
page (Opcional) solicitação de página atual
curl --location --request GET 'https://xcurt.com/api/splash?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Resposta do servidor

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "splash": [
            {
                "id": 1,
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "name": "Product 2 Promo",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}